@@ -1,24 +1,32 @@
-( cd usr/lib ; rm -rf libogmdvd.so.0 )
-( cd usr/lib ; ln -sf libogmdvd.so.0.0.0 libogmdvd.so.0 )
-( cd usr/lib ; rm -rf libogmrip-gtk.so )
-( cd usr/lib ; ln -sf libogmrip-gtk.so.0.0.0 libogmrip-gtk.so )
-( cd usr/lib ; rm -rf libogmrip-mplayer.so )
-( cd usr/lib ; ln -sf libogmrip-mplayer.so.0.0.0 libogmrip-mplayer.so )
-( cd usr/lib ; rm -rf libogmjob.so )
-( cd usr/lib ; ln -sf libogmjob.so.0.0.0 libogmjob.so )
-( cd usr/lib ; rm -rf libogmrip-gtk.so.0 )
-( cd usr/lib ; ln -sf libogmrip-gtk.so.0.0.0 libogmrip-gtk.so.0 )
-( cd usr/lib ; rm -rf libogmrip.so.0 )
-( cd usr/lib ; ln -sf libogmrip.so.0.0.0 libogmrip.so.0 )
-( cd usr/lib ; rm -rf libogmjob.so.0 )
-( cd usr/lib ; ln -sf libogmjob.so.0.0.0 libogmjob.so.0 )
-( cd usr/lib ; rm -rf libogmrip-mplayer.so.0 )
-( cd usr/lib ; ln -sf libogmrip-mplayer.so.0.0.0 libogmrip-mplayer.so.0 )
+( cd usr/bin ; rm -rf subp2png )
+( cd usr/bin ; ln -sf subp2pgm subp2png )
+( cd usr/bin ; rm -rf subp2tiff )
+( cd usr/bin ; ln -sf subp2pgm subp2tiff )
 ( cd usr/lib ; rm -rf libogmrip.so )
 ( cd usr/lib ; ln -sf libogmrip.so.0.0.0 libogmrip.so )
 ( cd usr/lib ; rm -rf libogmdvd-gtk.so )
 ( cd usr/lib ; ln -sf libogmdvd-gtk.so.0.0.0 libogmdvd-gtk.so )
+( cd usr/lib ; rm -rf libogmrip-lavc.so )
+( cd usr/lib ; ln -sf libogmrip-lavc.so.0.0.0 libogmrip-lavc.so )
 ( cd usr/lib ; rm -rf libogmdvd-gtk.so.0 )
 ( cd usr/lib ; ln -sf libogmdvd-gtk.so.0.0.0 libogmdvd-gtk.so.0 )
+( cd usr/lib ; rm -rf libogmjob.so )
+( cd usr/lib ; ln -sf libogmjob.so.0.0.0 libogmjob.so )
+( cd usr/lib ; rm -rf libogmdvd.so.0 )
+( cd usr/lib ; ln -sf libogmdvd.so.0.0.0 libogmdvd.so.0 )
 ( cd usr/lib ; rm -rf libogmdvd.so )
 ( cd usr/lib ; ln -sf libogmdvd.so.0.0.0 libogmdvd.so )
+( cd usr/lib ; rm -rf libogmrip-gtk.so )
+( cd usr/lib ; ln -sf libogmrip-gtk.so.0.0.0 libogmrip-gtk.so )
+( cd usr/lib ; rm -rf libogmrip-gtk.so.0 )
+( cd usr/lib ; ln -sf libogmrip-gtk.so.0.0.0 libogmrip-gtk.so.0 )
+( cd usr/lib ; rm -rf libogmrip.so.0 )
+( cd usr/lib ; ln -sf libogmrip.so.0.0.0 libogmrip.so.0 )
+( cd usr/lib ; rm -rf libogmrip-lavc.so.0 )
+( cd usr/lib ; ln -sf libogmrip-lavc.so.0.0.0 libogmrip-lavc.so.0 )
+( cd usr/lib ; rm -rf libogmrip-mplayer.so )
+( cd usr/lib ; ln -sf libogmrip-mplayer.so.0.0.0 libogmrip-mplayer.so )
+( cd usr/lib ; rm -rf libogmjob.so.0 )
+( cd usr/lib ; ln -sf libogmjob.so.0.0.0 libogmjob.so.0 )
+( cd usr/lib ; rm -rf libogmrip-mplayer.so.0 )
+( cd usr/lib ; ln -sf libogmrip-mplayer.so.0.0.0 libogmrip-mplayer.so.0 )
